pub struct WriteFlags(/* private fields */);Expand description
Write options.
Implementations
Sourceimpl WriteFlags
impl WriteFlags
Sourcepub const NO_OVERWRITE: Self
pub const NO_OVERWRITE: Self
Insert the new item only if the key does not already appear in the database.
The function will return LmdbError::KeyExist if the key already appears in the
database, even if the database supports duplicates (DUP_SORT).
Sourcepub const NO_DUP_DATA: Self
pub const NO_DUP_DATA: Self
Insert the new item only if it does not already appear in the database.
This flag may only be specified if the database was opened with DUP_SORT.
The function will return LmdbError::KeyExist if the item already appears in the
database.
Sourcepub const CURRENT: Self
pub const CURRENT: Self
For Cursor::put. Replace the item at the current cursor position. The key
parameter must match the current position. If using sorted duplicates (DUP_SORT)
the data item must still sort into the same position. This is intended to be used
when the new data is the same size as the old. Otherwise it will simply perform a
delete of the old record followed by an insert.
Sourcepub const APPEND: Self
pub const APPEND: Self
Append the given item to the end of the database. No key comparisons are performed. This option allows fast bulk loading when keys are already known to be in the correct order. Loading unsorted keys with this flag will cause data corruption.
Sourcepub const APPEND_DUP: Self
pub const APPEND_DUP: Self
Same as APPEND, but for sorted dup data.
Sourceimpl WriteFlags
impl WriteFlags
Sourcepub const fn bits(&self) -> c_uint
pub const fn bits(&self) -> c_uint
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_uint) -> Option<Self>
pub const fn from_bits(bits: c_uint) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_uint) -> Self
pub const fn from_bits_truncate(bits: c_uint) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_uint) -> Self
pub const fn from_bits_retain(bits: c_uint) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl WriteFlags
impl WriteFlags
Sourcepub const fn iter(&self) -> Iter<WriteFlags>
pub const fn iter(&self) -> Iter<WriteFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WriteFlags>
pub const fn iter_names(&self) -> IterNames<WriteFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.